@@ -1,5 +1,5 @@
 use biosphere::utils::{argsort, sample_indices_from_weights, sample_weights};
-use biosphere::{DecisionTree, DecisionTreeParameters};
+use biosphere::{DecisionTree, DecisionTreeParameters, MaxFeatures};
 
 #[cfg(test)]
 use criterion::{criterion_group, criterion_main, Criterion};
@@ -59,7 +59,7 @@ pub fn benchmark_tree(c: &mut Criterion) {
 
         let decision_tree_parameters = DecisionTreeParameters::default()
             .with_max_depth(Some(*max_depth))
-            .with_mtry(Some(*mtry));
+            .with_max_features(MaxFeatures::Value(*mtry));
         group.bench_function(
             format!(
                 "tree_n={}, d={}, max_depth={}, mtry={}",
